#
# Regular cron jobs for the jffnms package
#
#Paths
JFFNMS=/usr/share/jffnms/engine
PHP=/usr/bin/php

# Consolidator 
*/1  * * * *    jffnms cd $JFFNMS && $PHP -q consolidate.php >/dev/null 2>&1

# SLAs
*/30 * * * *    jffnms cd $JFFNMS && $PHP -q rrd_analizer.php >/dev/null 2>&1

# TFTP Configuration
02   4 * * *    jffnms cd $JFFNMS && $PHP -q tftp_get_host_config.php >/dev/null 2>&1

# Cleanup system
02   5 * * *    jffnms cd $JFFNMS && $PHP -q cleanup_raw_tables.php >/dev/null 2>&1
20   * * * *    jffnms cd $JFFNMS && sh tmpwatch.sh $JFFNMS >/dev/null 2>&1

# Current Poller
*/5  * * * *    jffnms cd $JFFNMS && $PHP -q poller.php >/dev/null 2>&1

# Interface Autodiscovery
*/30 * * * *    jffnms cd $JFFNMS && $PHP -q autodiscovery_interfaces.php > /dev/null 2>&1
